Module: Agris::Api::AccountsReceivables::Payments

Included in:
Client
Defined in:
lib/agris/api/accounts_receivables/payments.rb

Instance Method Summary collapse

Instance Method Details

#apply_payment(payment, allocation) ⇒ Object

Agris will not accept a receipt and its applications in one message, so each application posts against the receipt Agris allocated.



13
14
15
# File 'lib/agris/api/accounts_receivables/payments.rb', line 13

def apply_payment(payment, allocation)
  post_payment(payment.for_allocation(allocation))
end

#create_payment(payment) ⇒ Object



7
8
9
# File 'lib/agris/api/accounts_receivables/payments.rb', line 7

def create_payment(payment)
  post_payment(payment)
end